<?php
/*
    LWAT, LDAP Webbased Administration Tool
    Copyright (C) 2007 Finn-Arne Johansem <faj@bzz.no> BzzWare AS, Norway 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
    require_once ('functions.php') ;
    loadConfig () ; 
    require('/usr/share/php/smarty/libs/Smarty.class.php') ; 
    session_start() ;
    loadLocale () ; 
    ob_start ();
    $smarty = new Smarty();

    $smarty->template_dir = $smarty_templ ; 
    $smarty->compile_dir = $smarty_compile ; 

    $authenticated = false ; 
    $key = lwat_key () ; 
    $ldap = lwat_ldap () ; 

    if ($_GET['action'] == 'logout') {
	setcookie ('admindn', '', time () + 1800) ;
	setcookie ('xorstring', '', time () + 1800) ;
    } else 
        $authenticated = lwat_login ($ldap, 
                                     readKey('admindn'), 
                                     readKey('adminpw'),
                                     $key) ; 

    if ($authenticated) 
	$smarty->display('menu.tpl');
    else
	$smarty->display('login.tpl');
    ldap_close ($ldap) ; 
?>
